//
//  ViewController.swift
//  tv-first-test
//
//  Created by Michael Kofler on 29.04.16.
//  Copyright © 2016 Michael Kofler. All rights reserved.
//

import UIKit

class ViewController: UIViewController {

  @IBOutlet weak var outputText: UITextView!
  
  override func viewDidLoad() {
    super.viewDidLoad()
  }

  
  @IBAction func showDateTime(sender: UIButton) {
    let now = NSDate()
    outputText.text = now.descriptionWithLocale(NSLocale.currentLocale())
  }

  @IBAction func showMemory(sender: UIButton) {
    let gbyte = Double(1024*1024*1024)
    let ram = NSProcessInfo.processInfo().physicalMemory
    let flashtotal = deviceTotalInBytes()
    let flashfree = deviceRemainingFreeSpaceInBytes()
    
    // formatieren
    let fmt = NSNumberFormatter()
    fmt.minimumFractionDigits = 2
    fmt.maximumFractionDigits = 2
    let ramfmt   =
      fmt.stringFromNumber(Double(ram) / gbyte)!
    let flashfreefmt =
      fmt.stringFromNumber(Double(flashfree) / gbyte)!
    let flashtotalfmt =
      fmt.stringFromNumber(Double(flashtotal) / gbyte)!
    
    // ausgeben
    outputText.text =
      "Arbeitsspeicher (RAM, insgesamt):  \(ram) Byte = \(ramfmt) GByte\n" +
      "Gerätespeicher (Flash, insgesamt): \(flashtotalfmt) GByte\n" +
      "Gerätespeicher (Flash, noch frei): \(flashfreefmt) GByte"
  }
  
  @IBAction func showVersion(sender: UIButton) {
    let v = UIDevice.currentDevice().systemVersion
    outputText.text = "tvOS-Version \(v)"
  }
  
  @IBAction func showIpAddress(sender: UIButton) {
    var out = ""
    for s in getIPAddresses() {
      out += s + "\n"
    }
    outputText.text = "IP-Adresse(n): " + out
  }
  
  
  // Quelle: http://stackoverflow.com/questions/26198073
  func deviceRemainingFreeSpaceInBytes() -> Int64 {
    let documentDirectoryPath = NSSearchPathForDirectoriesInDomains(.DocumentDirectory, .UserDomainMask, true)
    if let systemAttributes = try? NSFileManager.defaultManager().attributesOfFileSystemForPath(documentDirectoryPath.last!) {
      if let freeSize = systemAttributes[NSFileSystemFreeSize] as? NSNumber {
        return freeSize.longLongValue
      }
    }
    return 0
  }
  func deviceTotalInBytes() -> Int64 {
    do {
      let systemAttributes = try NSFileManager.defaultManager().attributesOfFileSystemForPath(NSHomeDirectory() as String)
      let space = (systemAttributes[NSFileSystemSize] as? NSNumber)?.longLongValue
      return space!
    } catch {
      return 0
    }
    
  }
 
  // Quelle: http://stackoverflow.com/questions/25626117
 
  // erfordert eine weitere Objective-C-Datei mit der Zeile
  // #import <Foundation/Foundation.h>
  // sowie den von Xcode erzeugten Briding Header, siehe:
  // https://developer.apple.com/library/ios/documentation/Swift/Conceptual/BuildingCocoaApps/MixandMatch.html
  
  // tvOS hat anscheinend immer nur eine IP-Adresse, auch wenn WLAN und Ethernet gleichzeitig verfügbar sind.
  // In diesem Fall wird Ethernet der Vorzug gegeben.
  
  // Return IP address of WiFi interface (en0) as a String, or `nil`
  func getIPAddresses() -> [String] {
    var addresses = [String]()
    
    // Get list of all interfaces on the local machine:
    var ifaddr : UnsafeMutablePointer<ifaddrs> = nil
    if getifaddrs(&ifaddr) == 0 {
      
      // For each interface ...
      var ptr = ifaddr
      while ptr != nil {
        defer { ptr = ptr.memory.ifa_next }
        
        let flags = Int32(ptr.memory.ifa_flags)
        var addr = ptr.memory.ifa_addr.memory
        
        // Check for running IPv4, IPv6 interfaces. Skip the loopback interface.
        if (flags & (IFF_UP|IFF_RUNNING|IFF_LOOPBACK)) == (IFF_UP|IFF_RUNNING) {
          if addr.sa_family == UInt8(AF_INET) || addr.sa_family == UInt8(AF_INET6) {
            
            // Convert interface address to a human readable string:
            var hostname = [CChar](count: Int(NI_MAXHOST), repeatedValue: 0)
            if (getnameinfo(&addr, socklen_t(addr.sa_len), &hostname, socklen_t(hostname.count),
              nil, socklen_t(0), NI_NUMERICHOST) == 0) {
              if let address = String.fromCString(hostname) {
                addresses.append(address)
              }
            }
          }
        }
      }
      freeifaddrs(ifaddr)
    }
    
    return addresses
  }
}

